@@ -66,7 +66,6 @@ enum {
 	AUTOBROWSE,
 	AUTOBURN,
 	AUTOBURN_AUDIO_CD_COMMAND,
-	AUTOBURN_PHOTO_CD_COMMAND,
 	AUTOBURN_DATA_CD_COMMAND,
 	AUTOIPOD,
 	AUTOIPOD_COMMAND,
@@ -93,7 +92,6 @@ static struct {
 	{ GCONF_ROOT "autobrowse",                TYPE_BOOL,   &config.autobrowse                },
 	{ GCONF_ROOT "autoburn",                  TYPE_BOOL,   &config.autoburn                  },
 	{ GCONF_ROOT "autoburn_audio_cd_command", TYPE_STRING, &config.autoburn_audio_cd_command },
-	{ GCONF_ROOT "autoburn_photo_cd_command", TYPE_STRING, &config.autoburn_photo_cd_command },
 	{ GCONF_ROOT "autoburn_data_cd_command",  TYPE_STRING, &config.autoburn_data_cd_command  },
 	{ GCONF_ROOT "autoipod",                  TYPE_BOOL,   &config.autoipod                  },
 	{ GCONF_ROOT "autoipod_command",          TYPE_STRING, &config.autoipod_command          },
@@ -129,51 +127,63 @@ enum {
 	GVM_RESPONSE_SYNC_MUSIC,
 	GVM_RESPONSE_IMPORT_PHOTOS,
 	GVM_RESPONSE_BURN_AUDIO_CD,
-	GVM_RESPONSE_BURN_PHOTO_CD,
 	GVM_RESPONSE_BURN_DATA_CD,
 };
 
-static struct _GvmPromptButton GVM_BUTTONS_RUN_CANCEL[] = {
-	{ NULL, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL },
-	{ N_("_Run Command"), NULL, GVM_RESPONSE_RUN },
+static struct _GvmPromptButton GVM_BUTTONS_AUTORUN[] = {
+	{ N_("_Ignore"), NULL, GTK_RESPONSE_CANCEL },
+	{ N_("_Allow Auto-Run"), NULL, GVM_RESPONSE_RUN },
 };
 
-static struct _GvmPromptButton GVM_BUTTONS_IMPORT_CANCEL[] = {
-	{ NULL, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL },
-	{ N_("_Import Photos"), NULL, GVM_RESPONSE_IMPORT_PHOTOS },
+static struct _GvmPromptButton GVM_BUTTONS_CAMERA[] = {
+	{ N_("_Ignore"), NULL, GTK_RESPONSE_CANCEL },
+	{ N_("_Open Folder"), NULL, GVM_RESPONSE_BROWSE },
+	{ N_("Import _Photos"), NULL, GVM_RESPONSE_IMPORT_PHOTOS },
 };
 
-static struct _GvmPromptButton GVM_BUTTONS_IMPORT_SYNC_CANCEL[] = {
-	{ NULL, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL },
-	{ N_("_Import Photos"), NULL, GVM_RESPONSE_IMPORT_PHOTOS },
-	{ N_("_Sync Music"), NULL, GVM_RESPONSE_SYNC_MUSIC },
+static struct _GvmPromptButton GVM_BUTTONS_PTP_CAMERA[] = {
+	{ N_("_Ignore"), NULL, GTK_RESPONSE_CANCEL },
+	{ N_("Import _Photos"), NULL, GVM_RESPONSE_IMPORT_PHOTOS },
 };
 
-static struct _GvmPromptButton GVM_BUTTONS_BROWSE_PLAY_CANCEL[] = {
-	{ NULL, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL },
+static struct _GvmPromptButton GVM_BUTTONS_IPOD_PHOTO[] = {
+	{ N_("_Ignore"), NULL, GTK_RESPONSE_CANCEL },
+	{ N_("Import _Photos"), NULL, GVM_RESPONSE_IMPORT_PHOTOS },
+	{ N_("Manage _Music"), NULL, GVM_RESPONSE_SYNC_MUSIC },
+};
+
+static struct _GvmPromptButton GVM_BUTTONS_MIXED_CD[] = {
+	{ N_("_Ignore"), NULL, GTK_RESPONSE_CANCEL },
 	{ N_("_Browse Files"), NULL, GVM_RESPONSE_BROWSE },
-	{ N_("_Play Tracks"), NULL, GVM_RESPONSE_PLAY },
+	{ N_("_Play CD"), NULL, GVM_RESPONSE_PLAY },
 };
 
-static struct _GvmPromptButton GVM_BUTTONS_BURN_CDR_AUDIO_PHOTO_DATA[] = {
-	{ NULL, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL },
-	{ N_("Burn _Audio CD/DVD"), NULL, GVM_RESPONSE_BURN_AUDIO_CD },
-	{ N_("Burn _Photo CD/DVD"), NULL, GVM_RESPONSE_BURN_PHOTO_CD },
-	{ N_("Burn _Data CD/DVD"), NULL, GVM_RESPONSE_BURN_DATA_CD },
+static struct _GvmPromptButton GVM_BUTTONS_BURN_CD[] = {
+	{ N_("_Ignore"), NULL, GTK_RESPONSE_CANCEL },
+	{ N_("Make _Audio CD"), NULL, GVM_RESPONSE_BURN_AUDIO_CD },
+	{ N_("Make _Data CD"), NULL, GVM_RESPONSE_BURN_DATA_CD },
+};
+
+static struct _GvmPromptButton GVM_BUTTONS_BURN_DVD[] = {
+	{ N_("_Ignore"), NULL, GTK_RESPONSE_CANCEL },
+	{ N_("Make _DVD"), NULL, GVM_RESPONSE_BURN_DATA_CD },
 };
 
 typedef enum {
 	GVM_PROMPT_AUTORUN,
 	GVM_PROMPT_IMPORT_CAMERA,
+	GVM_PROMPT_IMPORT_PTP_CAMERA,
 	GVM_PROMPT_IMPORT_PHOTOS,
 	GVM_PROMPT_IPOD_PHOTO,
 	GVM_PROMPT_CDA_EXTRA,
 	GVM_PROMPT_BURN_CDR,
+	GVM_PROMPT_BURN_DVD,
 } GvmPrompt;
 
 static struct {
 	GtkDialogFlags flags;
-	GtkMessageType type;
+	
+	const char *icon;
 	
 	const char *help_uri;
 	
@@ -186,44 +196,67 @@ static struct {
 	const char *primary;
 	const char *secondary;
 	int secondary_has_args;
+	int secondary_has_mockup;
 	
-	const char *dont_ask_again_key;
-	const char *dont_ask_again_label;
+	const char *ask_again_key;
+	const char *ask_again_label;
 } gvm_prompts[] = {
-	{ 0, GTK_MESSAGE_QUESTION, NULL, GVM_BUTTONS_RUN_CANCEL, 2, GVM_RESPONSE_RUN,
-	  N_("Run command from inserted media?"),
-	  N_("Run command from inserted media?"),
-	  N_("Do you want to run the file \"%s?\""),
-	  TRUE, GCONF_ROOT "prompts/autorun", N_("Always take this action") },
-	{ 0, GTK_MESSAGE_QUESTION, NULL, GVM_BUTTONS_IMPORT_CANCEL, 2, GVM_RESPONSE_IMPORT_PHOTOS,
-	  N_("Import photos from camera?"),
-	  N_("Import photos from camera?"),
-	  N_("There are photos on the plugged-in camera. Would you like to import these photographs into your album?"),
-	  FALSE, GCONF_ROOT "prompts/camera_import_photos", N_("Always take this action") },
-	{ 0, GTK_MESSAGE_QUESTION, NULL, GVM_BUTTONS_IMPORT_CANCEL, 2, GVM_RESPONSE_IMPORT_PHOTOS,
-	  N_("Import photos from device?"),
-	  N_("Import photos from device?"),
-	  N_("There are photos on the inserted media. Would you like to import these photographs into your album?"),
-	  FALSE, GCONF_ROOT "prompts/device_import_photos", N_("Always take this action") },
-	{ 0, GTK_MESSAGE_QUESTION, NULL, GVM_BUTTONS_IMPORT_SYNC_CANCEL, 3, GVM_RESPONSE_SYNC_MUSIC,
-	  N_("Import photos or music?"),
-	  N_("Import photos or music?"),
-	  N_("There are both photos and music on the plugged-in iPod. "
-	     "Would you like to import the photos or would you prefer "
-	     "to sync your music?"),
-	  FALSE, GCONF_ROOT "prompts/ipod_photo", N_("Always take this action") },
-	{ 0, GTK_MESSAGE_QUESTION, NULL, GVM_BUTTONS_BROWSE_PLAY_CANCEL, 3, GVM_RESPONSE_PLAY,
-	  N_("Browse files or play tracks from disc?"),
-	  N_("Browse files or play tracks from disc?"),
-	  N_("There are both audio tracks and data files on the inserted disc. "
-	     "Would you like to play the audio tracks to listen to music or browse the "
-	     "files to manage the stored data."),
-	  FALSE, GCONF_ROOT "prompts/cd_mixed", N_("Always take this action") },
-	{ 0, GTK_MESSAGE_QUESTION, NULL, GVM_BUTTONS_BURN_CDR_AUDIO_PHOTO_DATA, 4, GVM_RESPONSE_BURN_DATA_CD,
-	  N_("Burn audio, photo, or data cd?"),
-	  N_("Burn audio, photo, or data cd?"),
-	  N_("Would you like to burn an audio, photo, or data CD/DVD?"),
-	  FALSE, GCONF_ROOT "prompts/burn_cd", N_("Always take this action") },
+	{ 0, "gnome-fs-executable", NULL,
+	  GVM_BUTTONS_AUTORUN, G_N_ELEMENTS (GVM_BUTTONS_AUTORUN),
+	  GVM_RESPONSE_RUN,
+	  N_("Auto-Run Confirmation"),
+	  N_("Auto-run capability detected."),
+	  N_("Would you like to allow <b>'${0}'</b> to run?"), TRUE, TRUE,
+	  NULL, NULL },
+	{ 0, "applets-screenshooter", NULL,
+	  GVM_BUTTONS_CAMERA, G_N_ELEMENTS (GVM_BUTTONS_CAMERA),
+	  GVM_RESPONSE_IMPORT_PHOTOS,
+	  N_("Camera Import"),
+	  N_("A camera has been detected."),
+	  N_("There are photos on the camera. Would you like to add these pictures to your album?"), FALSE, FALSE,
+	  GCONF_ROOT "prompts/camera_import_photos", N_("_Always perform this action") },
+	{ 0, "applets-screenshooter", NULL,
+	  GVM_BUTTONS_PTP_CAMERA, G_N_ELEMENTS (GVM_BUTTONS_PTP_CAMERA),
+	  GVM_RESPONSE_IMPORT_PHOTOS,
+	  N_("Camera Import"),
+	  N_("A camera has been detected."),
+	  N_("There are photos on the camera. Would you like to add these pictures to your album?"), FALSE, FALSE,
+	  GCONF_ROOT "prompts/ptp_camera_import_photos", N_("_Always perform this action") },
+	{ 0, "applets-screenshooter", NULL,
+	  GVM_BUTTONS_CAMERA, G_N_ELEMENTS (GVM_BUTTONS_CAMERA),
+	  GVM_RESPONSE_IMPORT_PHOTOS,
+	  N_("Photo Import"),
+	  N_("A photo card has been detected."),
+	  N_("There are photos on the card. Would you like to add these pictures to your album?"), FALSE, FALSE,
+	  GCONF_ROOT "prompts/device_import_photos", N_("_Always perform this action") },
+	{ 0, "gnome-dev-ipod", NULL,
+	  GVM_BUTTONS_IPOD_PHOTO, G_N_ELEMENTS (GVM_BUTTONS_IPOD_PHOTO),
+	  GVM_RESPONSE_SYNC_MUSIC,
+	  N_("Photos and Music"),
+	  N_("Photos were found on your music device."),
+	  N_("Would you like to import the photos or manage its music?"), FALSE, FALSE,
+	  GCONF_ROOT "prompts/ipod_photo", N_("_Always perform this action") },
+	{ 0, "gnome-dev-cdrom-audio", NULL,
+	  GVM_BUTTONS_MIXED_CD, G_N_ELEMENTS (GVM_BUTTONS_MIXED_CD),
+	  GVM_RESPONSE_PLAY,
+	  N_("Audio / Data CD"),
+	  N_("The CD in the drive contains both music and files."),
+	  N_("Would you like to listen to music or browse the files?"), FALSE, FALSE,
+	  GCONF_ROOT "prompts/cd_mixed", N_("_Always perform this action") },
+	{ 0, "gnome-dev-cdrom", NULL,
+	  GVM_BUTTONS_BURN_CD, G_N_ELEMENTS (GVM_BUTTONS_BURN_CD),
+	  GVM_RESPONSE_BURN_DATA_CD,
+	  N_("Choose Disc Type"),
+	  N_("You have inserted an empty disc."),
+	  N_("What would you like to do?"), FALSE, FALSE,
+	  NULL, NULL },
+	{ 0, "gnome-dev-disc-dvdr", NULL,
+	  GVM_BUTTONS_BURN_DVD, G_N_ELEMENTS (GVM_BUTTONS_BURN_DVD),
+	  GVM_RESPONSE_BURN_DATA_CD,
+	  N_("Choose Disc Type"),
+	  N_("You have inserted an empty disc."),
+	  N_("What would you like to do?"), FALSE, FALSE,
+	  NULL, NULL },
 };
 
 static void
@@ -243,24 +276,62 @@ prompt_response_cb (GtkWidget *dialog, int response, gpointer user_data)
 	}
 }
 
-static int
-gvm_prompt (GvmPrompt prompt, ...)
+static char *
+argv_expand (const char *format, int argc, char **argv)
 {
-	GtkWidget *dialog, *hbox, *image, *label, *check = NULL;
-	const char *stock_id = NULL;
+	const char *start, *inptr;
+	GString *string;
+	char *str;
+	int i;
+	
+	string = g_string_new ("");
+	start = inptr = format;
+	
+	while (*inptr) {
+		while (*inptr) {
+			if (inptr[0] == '$' && inptr[1] == '{' && inptr[2] >= '0' && inptr[2] <= '9')
+				break;
+			inptr++;
+		}
+		
+		if (*inptr == '\0')
+			break;
+		
+		g_string_append_len (string, start, inptr - start);
+		
+		start = inptr;
+		inptr += 2;
+		i = strtol (inptr, &str, 10);
+		if (*str == '}' && i < argc) {
+			start = inptr = str + 1;
+			g_string_append (string, argv[i]);
+		}
+	}
+	
+	g_string_append (string, start);
+	
+	str = string->str;
+	g_string_free (string, FALSE);
+	
+	return str;
+}
+
+static int
+gvm_prompt (GvmPrompt prompt, int argc, char **argv)
+{
+	GtkWidget *dialog, *hbox, *vbox, *image, *label, *check = NULL;
+	GnomeIconTheme *theme;
 	GConfClient *gconf;
 	GError *err = NULL;
-	GtkStockItem item;
+	const char *text;
 	int response, i;
-	GString *str;
-	va_list args;
-	char *text;
+	char *buf;
 	
 	gconf = gconf_client_get_default ();
 	
 	/* don't prompt the user again if she's already chosen a default action and has asked to not be prompetd again */
-	if (gvm_prompts[prompt].dont_ask_again_key) {
-		response = gconf_client_get_int (gconf, gvm_prompts[prompt].dont_ask_again_key, &err);
+	if (gvm_prompts[prompt].ask_again_key) {
+		response = gconf_client_get_int (gconf, gvm_prompts[prompt].ask_again_key, &err);
 		if (response > GVM_RESPONSE_NONE && err == NULL)
 			return response;
 		if (err != NULL)
@@ -274,6 +345,9 @@ gvm_prompt (GvmPrompt prompt, ...)
 	gtk_container_set_border_width ((GtkContainer *) ((GtkDialog *) dialog)->vbox, 0);
 	gtk_container_set_border_width ((GtkContainer *) ((GtkDialog *) dialog)->action_area, 12);
 	
+	if (gvm_prompts[prompt].title)
+		gtk_window_set_title ((GtkWindow *) dialog, _(gvm_prompts[prompt].title));
+	
 	if (gvm_prompts[prompt].flags & GTK_DIALOG_MODAL)
 		gtk_window_set_modal ((GtkWindow *) dialog, TRUE);
 	
@@ -302,75 +376,74 @@ gvm_prompt (GvmPrompt prompt, ...)
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_container_set_border_width ((GtkContainer *) hbox, 12);
 	
-	switch (gvm_prompts[prompt].type) {
-	case GTK_MESSAGE_INFO:
-		stock_id = GTK_STOCK_DIALOG_INFO;
-		break;
-	case GTK_MESSAGE_QUESTION:
-		stock_id = GTK_STOCK_DIALOG_QUESTION;
-		break;
-	case GTK_MESSAGE_WARNING:
-		stock_id = GTK_STOCK_DIALOG_WARNING;
-		break;
-	case GTK_MESSAGE_ERROR:
-		stock_id = GTK_STOCK_DIALOG_ERROR;
-		break;
-	default:
-		stock_id = GTK_STOCK_DIALOG_INFO;
-		break;
+	/* set the icon */
+	theme = gnome_icon_theme_new ();
+	image = gtk_image_new ();
+	
+	if ((buf = gnome_icon_theme_lookup_icon (theme, gvm_prompts[prompt].icon, 48, NULL, NULL))) {
+		gtk_image_set_from_file ((GtkImage *) image, buf);
+		g_free (buf);
+	} else {
 	}
 	
-	image = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_DIALOG);
 	gtk_misc_set_alignment ((GtkMisc *) image, 0.0, 0.0);
-	gtk_box_pack_start ((GtkBox *) hbox, image, TRUE, TRUE, 12);
+	gtk_box_pack_start ((GtkBox *) hbox, image, FALSE, FALSE, 12);
 	gtk_widget_show (image);
 	
-	if (gvm_prompts[prompt].title)
-		gtk_window_set_title ((GtkWindow *) dialog, _(gvm_prompts[prompt].title));
-	else if (gtk_stock_lookup (stock_id, &item))
-		gtk_window_set_title ((GtkWindow *) dialog, item.label);
+	vbox = gtk_vbox_new (FALSE, 0);
+	gtk_box_pack_start ((GtkBox *) hbox, vbox, FALSE, FALSE, 0);
 	
-	/* build the primary and secondary text */
-	str = g_string_new ("");
+	/* build the primary text */
+	buf = g_strdup_printf ("<span weight=\"bold\" size=\"larger\">%s</span>", _(gvm_prompts[prompt].primary));
 	
-	g_string_append (str, "<span weight=\"bold\" size=\"larger\">");
-	g_string_append (str, _(gvm_prompts[prompt].primary));
-	g_string_append (str, "</span>\n\n");
+	label = gtk_label_new (NULL);
+	gtk_misc_set_alignment ((GtkMisc *) label, 0.0, 0.5);
+	gtk_label_set_line_wrap ((GtkLabel *) label, FALSE);
+	gtk_label_set_markup ((GtkLabel *) label, buf);
+	g_free (buf);
 	
+	gtk_box_pack_start ((GtkBox *) vbox, label, FALSE, FALSE, 0);
+	gtk_widget_show (label);
+	
+	/* build the secondary text */
+	buf = NULL;
 	if (gvm_prompts[prompt].secondary_has_args) {
-		va_start (args, prompt);
-		text = g_strdup_vprintf (_(gvm_prompts[prompt].secondary), args);
-		va_end (args);
-		
-		g_string_append (str, text);
-		g_free (text);
+		text = buf = argv_expand (_(gvm_prompts[prompt].secondary), argc, argv);
 	} else {
-		g_string_append (str, _(gvm_prompts[prompt].secondary));
+		text = _(gvm_prompts[prompt].secondary);
 	}
 	
 	label = gtk_label_new (NULL);
-	gtk_label_set_selectable ((GtkLabel *) label, TRUE);
+	gtk_misc_set_alignment ((GtkMisc *) label, 0.0, 0.5);
+	/*gtk_label_set_selectable ((GtkLabel *) label, TRUE);*/
 	gtk_label_set_line_wrap ((GtkLabel *) label, TRUE);
-	gtk_label_set_markup ((GtkLabel *) label, str->str);
+	if (gvm_prompts[prompt].secondary_has_mockup)
+		gtk_label_set_markup ((GtkLabel *) label, text);
+	else
+		gtk_label_set_text ((GtkLabel *) label, text);
+	g_free (buf);
 	
-	gtk_box_pack_start ((GtkBox *) hbox, label, FALSE, FALSE, 0);
+	gtk_box_pack_start ((GtkBox *) vbox, label, FALSE, FALSE, 6);
 	gtk_widget_show (label);
 	
-	gtk_box_pack_start ((GtkBox *) ((GtkDialog *) dialog)->vbox, hbox, TRUE, TRUE, 0);
-	gtk_widget_show (hbox);
+	gtk_box_pack_start ((GtkBox *) ((GtkDialog *) dialog)->vbox, hbox, FALSE, FALSE, 0);
 	
 	/* conditionally add a checkbox to never bother the user again */
-	if (gvm_prompts[prompt].dont_ask_again_key && gvm_prompts[prompt].dont_ask_again_label) {
-		check = gtk_check_button_new_with_label (_(gvm_prompts[prompt].dont_ask_again_label));
-		gtk_container_set_border_width ((GtkContainer *) check, 12);
-		gtk_box_pack_start ((GtkBox *) ((GtkDialog *) dialog)->vbox, check, TRUE, TRUE, 0);
+	if (gvm_prompts[prompt].ask_again_key && gvm_prompts[prompt].ask_again_label) {
+		check = gtk_check_button_new_with_mnemonic (_(gvm_prompts[prompt].ask_again_label));
+		gtk_container_set_border_width ((GtkContainer *) check, 0);
+		gtk_box_pack_start ((GtkBox *) vbox, check, FALSE, FALSE, 0);
 		gtk_widget_show (check);
 	}
 	
+	gtk_widget_show (vbox);
+	gtk_widget_show (hbox);
+	
 	response = gtk_dialog_run ((GtkDialog *) dialog);
 	
-	if (check != NULL && gtk_toggle_button_get_active ((GtkToggleButton *) check))
-		gconf_client_set_int (gconf, gvm_prompts[prompt].dont_ask_again_key, response, NULL);
+	if (check != NULL && gtk_toggle_button_get_active ((GtkToggleButton *) check)
+	    && response != GTK_RESPONSE_CANCEL)
+		gconf_client_set_int (gconf, gvm_prompts[prompt].ask_again_key, response, NULL);
 	
 	gtk_widget_destroy (dialog);
 	g_object_unref (gconf);
@@ -549,6 +622,7 @@ gvm_run_command (const char *command, const char *udi, const char *device, const
 	argv[2] = exec->str;
 	argv[3] = NULL;
 	
+	dbg ("executing command: %s\n", exec->str);
 	if (!g_spawn_async (g_get_home_dir (), argv, NULL, 0, NULL, NULL, NULL, &error)) {
 		warn ("failed to exec %s: %s", exec->str, error->message);
 		g_string_free (exec, TRUE);
@@ -569,7 +643,14 @@ gvm_run_command (const char *command, const char *udi, const char *device, const
 static gboolean
 gvm_ask_autorun (const char *path)
 {
-	return gvm_prompt (GVM_PROMPT_AUTORUN, path) == GVM_RESPONSE_RUN;
+	gboolean autorun;
+	char *argv[1];
+	
+	argv[0] = g_path_get_basename (path);
+	autorun = gvm_prompt (GVM_PROMPT_AUTORUN, 1, argv) == GVM_RESPONSE_RUN;
+	g_free (argv[0]);
+	
+	return autorun;
 }
 
 /*
@@ -809,7 +890,7 @@ gvm_autorun (const char *udi, const char *device, const char *mount_point)
 		return;
 	
 	if (config.autophoto && gvm_check_photos (udi, device, mount_point)) {
-		if (gvm_prompt (GVM_PROMPT_IMPORT_PHOTOS) == GVM_RESPONSE_IMPORT_PHOTOS) {
+		if (gvm_prompt (GVM_PROMPT_IMPORT_PHOTOS, 0, NULL) == GVM_RESPONSE_IMPORT_PHOTOS) {
 			gvm_run_camera (udi, device, mount_point);
 			return;
 		}
@@ -855,6 +936,28 @@ gvm_autorun (const char *udi, const char *device, const char *mount_point)
 		gvm_run_command (NAUTILUS_COMMAND, udi, device, mount_point);
 }
 
+static gboolean
+gvm_udi_is_subfs_mount (const char *udi)
+{
+	int subfs = FALSE;
+	char **callouts;
+	int i;
+	
+	if ((callouts = libhal_device_get_property_strlist (hal_ctx, udi, "info.callouts.add", NULL))) {
+		for (i = 0; callouts[i] != NULL; i++) {
+			if (!strcmp (callouts[i], "hald-block-subfs")) {
+				dbg ("subfs to handle mounting of %s; skipping\n", udi);
+				subfs = TRUE;
+				break;
+			}
+		}
+		
+		libhal_free_string_array (callouts);
+	}
+	
+	return subfs;
+}
+
 /*
  * gvm_device_mounted - called once a device has been
  * mounted. Launches any user-specified applications that require the
@@ -885,8 +988,16 @@ gvm_device_mounted (const char *udi)
 	
 	/* this is where the magic happens */
 	if (config.autophoto && gvm_udi_is_camera (udi)) {
-		if (gvm_prompt (GVM_PROMPT_IMPORT_CAMERA) == GVM_RESPONSE_IMPORT_PHOTOS)
+		switch (gvm_prompt (GVM_PROMPT_IMPORT_CAMERA, 0, NULL)) {
+		case GVM_RESPONSE_IMPORT_PHOTOS:
 			gvm_run_camera (udi, device, mount_point);
+			break;
+		case GVM_RESPONSE_BROWSE:
+			gvm_run_command (NAUTILUS_COMMAND, udi, device, mount_point);
+			break;
+		default:
+			break;
+		}
 	} else if (config.autoipod && gvm_udi_is_ipod (udi)) {
 		int action = GVM_RESPONSE_SYNC_MUSIC;
 		char *ipod_control;
@@ -895,7 +1006,7 @@ gvm_device_mounted (const char *udi)
 		
 		if (gvm_check_photos (udi, device, ipod_control)) {
 			/* we have ourselves an iPod Photo - need to prompt what to do */
-			action = gvm_prompt (GVM_PROMPT_IPOD_PHOTO);
+			action = gvm_prompt (GVM_PROMPT_IPOD_PHOTO, 0, NULL);
 		}
 		
 		switch (action) {
@@ -919,27 +1030,6 @@ gvm_device_mounted (const char *udi)
 	libhal_free_string (device);
 }
 
-static gboolean
-gvm_udi_is_subfs_mount (const char *udi)
-{
-	int subfs = FALSE;
-	char **callouts;
-	int i;
-	
-	if ((callouts = libhal_device_get_property_strlist (hal_ctx, udi, "info.callouts.add", NULL))) {
-		for (i = 0; callouts[i] != NULL; i++) {
-			if (!strcmp (callouts[i], "hald-block-subfs")) {
-				dbg ("subfs to handle mounting of %s; skipping\n", udi);
-				subfs = TRUE;
-				break;
-			}
-		}
-		
-		libhal_free_string_array (callouts);
-	}
-	
-	return subfs;
-}
 
 /*
  * gvm_device_mount - mount the given device.
@@ -1011,7 +1101,7 @@ gvm_ask_mixed (const char *udi)
 	}
 	
 	if (config.automount_media && config.autoplay_cda) {
-		action = gvm_prompt (GVM_PROMPT_CDA_EXTRA);
+		action = gvm_prompt (GVM_PROMPT_CDA_EXTRA, 0, NULL);
 	} else if (config.automount_media) {
 		action = GVM_RESPONSE_BROWSE;
 	} else if (config.autoplay_cda) {
@@ -1020,9 +1110,7 @@ gvm_ask_mixed (const char *udi)
 	
 	switch (action) {
 	case GVM_RESPONSE_BROWSE:
-		if (gvm_udi_is_subfs_mount (udi))
-			gvm_device_mounted (udi);
-		else
+		if (!gvm_udi_is_subfs_mount (udi))
 			gvm_device_mount (udi, device, NULL);
 		break;
 	case GVM_RESPONSE_PLAY:
@@ -1037,41 +1125,16 @@ gvm_ask_mixed (const char *udi)
 	libhal_free_string (mount_point);
 }
 
-/*
- * gvm_run_cdburner - execute the user-specified CD burner command on the
- * given device node, if so configured
- */
-static void
-gvm_run_cdburner (const char *udi, const char *device, const char *mount_point)
-{
-	const char *command;
-	int action;
-	
-	if (!config.autoburn)
-		return;
-	
-	action = gvm_prompt (GVM_PROMPT_BURN_CDR);
-	switch (action) {
-	case GVM_RESPONSE_BURN_AUDIO_CD:
-		command = config.autoburn_audio_cd_command;
-		break;
-	case GVM_RESPONSE_BURN_PHOTO_CD:
-		command = config.autoburn_photo_cd_command;
-		break;
-	case GVM_RESPONSE_BURN_DATA_CD:
-		command = config.autoburn_data_cd_command;
-		break;
-	default:
-		return;
-	}
-	
-	gvm_run_command (command, udi, device, mount_point);
-}
+enum {
+	WRITER_TYPE_NONE,
+	WRITER_TYPE_CDR,
+	WRITER_TYPE_DVD
+};
 
 /*
- * gvm_device_is_writer - is this device capable of writing CDs?
+ * gvm_device_is_writer - is this device capable of writing CDs/DVDs?
  */
-static gboolean
+static int
 gvm_device_is_writer (const char *udi)
 {
 	static const char *writers[] = {
@@ -1085,13 +1148,54 @@ gvm_device_is_writer (const char *udi)
 	size_t i;
 	
 	for (i = 0; i < G_N_ELEMENTS (writers); i++) {
-		if (libhal_device_get_property_bool (hal_ctx, udi, writers[i], NULL))
-			return TRUE;
+		if (libhal_device_get_property_bool (hal_ctx, udi, writers[i], NULL)) {
+			const char *type;
+			
+			type = strrchr (writers[i], '.') + 1;
+			if (!strncmp (type, "dvd", 3))
+				return WRITER_TYPE_DVD;
+			else
+				return WRITER_TYPE_CDR;
+		}
 	}
 	
-	return FALSE;
+	return WRITER_TYPE_NONE;
 }
 
+
+/*
+ * gvm_run_cdburner - execute the user-specified CD burner command on the
+ * given device node, if so configured
+ */
+static void
+gvm_run_cdburner (const char *udi, int type, const char *device, const char *mount_point)
+{
+	const char *command;
+	int action;
+	
+	if (!config.autoburn)
+		return;
+	
+	if (type == WRITER_TYPE_DVD)
+		action = gvm_prompt (GVM_PROMPT_BURN_DVD, 0, NULL);
+	else
+		action = gvm_prompt (GVM_PROMPT_BURN_CDR, 0, NULL);
+	
+	switch (action) {
+	case GVM_RESPONSE_BURN_AUDIO_CD:
+		command = config.autoburn_audio_cd_command;
+		break;
+	case GVM_RESPONSE_BURN_DATA_CD:
+		command = config.autoburn_data_cd_command;
+		break;
+	default:
+		return;
+	}
+	
+	gvm_run_command (command, udi, device, mount_point);
+}
+
+
 /*
  * gvm_cdrom_policy - There has been a media change event on the CD-ROM
  * associated with the given UDI.  Enforce policy.
@@ -1105,6 +1209,7 @@ gvm_cdrom_policy (const char *udi)
 	dbus_bool_t has_data;
 	dbus_bool_t is_blank;
 	DBusError error;
+	int type;
 	
 	dbus_error_init (&error);
 	has_audio = libhal_device_get_property_bool (hal_ctx, udi, "volume.disc.has_audio", NULL);
@@ -1126,15 +1231,11 @@ gvm_cdrom_policy (const char *udi)
 	} else if (has_audio && has_data) {
 		gvm_ask_mixed (udi);
 	} else if (has_data) {
-		if (config.automount_media) {
-			if (!gvm_udi_is_subfs_mount (udi))
-				gvm_device_mount (udi, device, NULL);
-			else
-				gvm_device_mounted (udi);
-		}
+		if (config.automount_media && !gvm_udi_is_subfs_mount (udi))
+			gvm_device_mount (udi, device, NULL);
 	} else if (is_blank) {
-		if (gvm_device_is_writer (drive_udi))
-			gvm_run_cdburner (udi, device, NULL);
+		if ((type = gvm_device_is_writer (drive_udi)))
+			gvm_run_cdburner (udi, type, device, NULL);
 	}
 	
 	/** @todo enforce policy for all the new disc types now supported */
@@ -1286,8 +1387,6 @@ hal_device_added (LibHalContext *ctx __attribute__((__unused__)),
 				} else {
 					dbg ("storage.automount_enabled_hint set to false on %s, not mounting\n", udi);
 				}
-			} else {
-				gvm_device_mounted (udi);
 			}
 		}
 	} else if (libhal_device_query_capability (hal_ctx, udi, "input", NULL)) {
@@ -1320,7 +1419,7 @@ hal_device_added (LibHalContext *ctx __attribute__((__unused__)),
 			gvm_run_printer (udi);
 	} else if (gvm_udi_is_ptp_camera (udi)) {
 		/* if the device is a PTP camera with libgphoto2 support, launch the user-specified application */
-		if (config.autophoto && gvm_prompt (GVM_PROMPT_IMPORT_CAMERA) == GVM_RESPONSE_IMPORT_PHOTOS)
+		if (config.autophoto && gvm_prompt (GVM_PROMPT_IMPORT_PTP_CAMERA, 0, NULL) == GVM_RESPONSE_IMPORT_PHOTOS)
 			gvm_run_camera (udi, NULL, NULL);
 	}
 	
@@ -1403,11 +1502,11 @@ hal_property_modified (LibHalContext *ctx __attribute__((__unused__)),
 			
 			/* add to list of all volumes mounted during lifetime */
 			mounted_volumes = g_slist_append (mounted_volumes, g_strdup (udi));
-			
-			gvm_device_mounted (udi);
 		} else {
 			dbg ("not in mount queue: %s\n", udi);
 		}
+		
+		gvm_device_mounted (udi);
 	} else {
 		dbg ("Unmounted: %s\n", udi);
 		
@@ -1593,7 +1692,7 @@ mount_all (LibHalContext *ctx)
 			continue;
 		
 		/* mount the device */
-		if (!(dev = libhal_device_get_property_string (ctx, udi, "block.device", &error))) {
+		if ((dev = libhal_device_get_property_string (ctx, udi, "block.device", &error))) {
 			dbg ("mount_all: mounting %s\n", dev);
 			gvm_device_mount (udi, dev, NULL);
 			libhal_free_string (dev);
@@ -1624,8 +1723,7 @@ unmount_all (LibHalContext *ctx)
 	for (l = mounted_volumes; l != NULL; l = g_slist_next (l)) {
 		udi = l->data;
 		
-		device = libhal_device_get_property_string (ctx, udi, "block.device", &error);
-		if (device != NULL) {
+		if ((device = libhal_device_get_property_string (ctx, udi, "block.device", &error))) {
 			dbg ("unmount_all: unmounting %s\n", device);
 			gvm_device_unmount (udi, device, NULL);
 			libhal_free_string (device);
