@@ -34,12 +34,15 @@ enum {
 	AUTOBROWSE,
 	AUTOBURN,
 	AUTOBURN_AUDIO_CD_COMMAND,
-	AUTOBURN_PHOTO_CD_COMMAND,
 	AUTOBURN_DATA_CD_COMMAND,
 	AUTOIPOD,
 	AUTOIPOD_COMMAND,
+	AUTOKEYBOARD,
+	AUTOKEYBOARD_COMMAND,
 	AUTOMOUNT_DRIVES,
 	AUTOMOUNT_MEDIA,
+	AUTOMOUSE,
+	AUTOMOUSE_COMMAND,
 	AUTOPHOTO,
 	AUTOPHOTO_COMMAND,
 	AUTOPLAY_CDA,
@@ -49,6 +52,12 @@ enum {
 	AUTOPRINTER,
 	AUTOPRINTER_COMMAND,
 	AUTORUN,
+	AUTOSCANNER,
+	AUTOSCANNER_COMMAND,
+	AUTOTABLET,
+	AUTOTABLET_COMMAND,
+	AUTOVIDEOCAM,
+	AUTOVIDEOCAM_COMMAND,
 	AUTORUN_PATH,
 	EJECT_COMMAND,
 };
@@ -62,12 +71,15 @@ static struct {
 	{ GCONF_ROOT "autobrowse",                TYPE_BOOL,   NULL, TRUE  },
 	{ GCONF_ROOT "autoburn",                  TYPE_BOOL,   NULL, FALSE },
 	{ GCONF_ROOT "autoburn_audio_cd_command", TYPE_STRING, NULL, FALSE },
-	{ GCONF_ROOT "autoburn_photo_cd_command", TYPE_STRING, NULL, FALSE },
 	{ GCONF_ROOT "autoburn_data_cd_command",  TYPE_STRING, NULL, FALSE },
 	{ GCONF_ROOT "autoipod",                  TYPE_BOOL,   NULL, TRUE  },
 	{ GCONF_ROOT "autoipod_command",          TYPE_STRING, NULL, FALSE },
+	{ GCONF_ROOT "autokeyboard",              TYPE_BOOL,   NULL, TRUE  },
+	{ GCONF_ROOT "autokeyboard_command",      TYPE_STRING, NULL, FALSE },
 	{ GCONF_ROOT "automount_drives",          TYPE_BOOL,   NULL, TRUE  },
 	{ GCONF_ROOT "automount_media",           TYPE_BOOL,   NULL, TRUE  },
+	{ GCONF_ROOT "automouse",                 TYPE_BOOL,   NULL, TRUE  },
+	{ GCONF_ROOT "automouse_command",         TYPE_STRING, NULL, FALSE },
 	{ GCONF_ROOT "autophoto",                 TYPE_BOOL,   NULL, TRUE  },
 	{ GCONF_ROOT "autophoto_command",         TYPE_STRING, NULL, FALSE },
 	{ GCONF_ROOT "autoplay_cda",              TYPE_BOOL,   NULL, TRUE  },
@@ -77,6 +89,12 @@ static struct {
 	{ GCONF_ROOT "autoprinter",               TYPE_BOOL,   NULL, TRUE  },
 	{ GCONF_ROOT "autoprinter_command",       TYPE_STRING, NULL, FALSE },
 	{ GCONF_ROOT "autorun",                   TYPE_BOOL,   NULL, TRUE  },
+	{ GCONF_ROOT "autoscanner",               TYPE_BOOL,   NULL, TRUE  },
+	{ GCONF_ROOT "autoscanner_command",       TYPE_STRING, NULL, FALSE },
+	{ GCONF_ROOT "autotablet",                TYPE_BOOL,   NULL, TRUE  },
+	{ GCONF_ROOT "autotablet_command",        TYPE_STRING, NULL, FALSE },
+	{ GCONF_ROOT "autovideocam",              TYPE_BOOL,   NULL, TRUE  },
+	{ GCONF_ROOT "autovideocam_command",      TYPE_STRING, NULL, FALSE },
 	/* The following entries do not yet have a UI */
 	/*{ GCONF_ROOT "autorun_path",         TYPE_STRING, NULL, FALSE },
 	  { GCONF_ROOT "eject_command",        TYPE_STRING, NULL, FALSE },*/
@@ -263,6 +281,18 @@ show_props (void)
 	set_icon (GTK_IMAGE (icon), icon_theme, "gnome-dev-ipod");
 	icon = glade_xml_get_widget (xml, "printer_image");
 	set_icon (GTK_IMAGE (icon), icon_theme, "gnome-dev-printer");
+	icon = glade_xml_get_widget (xml, "scanner_image");
+	set_icon (GTK_IMAGE (icon), icon_theme, "xsane");
+	icon = glade_xml_get_widget (xml, "keyboard_image");
+	set_icon (GTK_IMAGE (icon), icon_theme, "gnome-dev-keyboard");
+	icon = glade_xml_get_widget (xml, "mouse_image");
+	set_icon (GTK_IMAGE (icon), icon_theme, "gnome-dev-mouse-optical");
+	/* FIXME: need better icon */
+	icon = glade_xml_get_widget (xml, "tablet_image");
+	set_icon (GTK_IMAGE (icon), icon_theme, "gnome-dev-mouse-optical");
+	/* FIXME: need better icon */
+	icon = glade_xml_get_widget (xml, "videocam_image");
+	set_icon (GTK_IMAGE (icon), icon_theme, "gnome-mime-video");
 	
 	gtk_window_set_default_icon_name ("gnome-dev-cdrom");
 	
@@ -442,7 +472,7 @@ main (int argc, char **argv)
 						 _("Volume management not supported"));
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
 							  _("The \"hald\" service is required but not currently "
-							    "running. Enable the service and rerun this applet, "
+							    "running. Enable the service and rerun this application, "
 							    "or contact your system administrator.\n\n"
 							    "Note: You need Linux kernel 2.6 for volume "
 							    "management to work."));
